@@ -538,7 +538,8 @@ class BatteryStateWithoutLastEvent(BaseStateWithoutLastEvent, BatterySetEvent):
 
 
 class FrameState(MotionState):
-    frame: bytes
+    frame_id: str
+    metadata: "FrameMetadata"
 
 
 T = TypeVar(
@@ -707,7 +708,7 @@ class ImageOptions(TypedDict):
     resize: NotRequired[ImageResize]
 
 
-ImageInputFormat = Literal["yuv", "rgb", "rgba"]
+ImageInputFormat = Literal["yuv", "rgb", "rgba", "gray"]
 
 
 class IceServer(TypedDict):
@@ -746,19 +747,15 @@ class FrameImage(TypedDict):
 
 
 class VideoFrame(Protocol):
-    image_buffer: bytes
+    frame_id: str
+    metadata: FrameMetadata
+    input_width: int
+    input_height: int
+    input_format: DecoderFormat
 
-    @property
-    def metadata(self) -> FrameMetadata: ...
-    @property
-    def input_width(self) -> int: ...
-    @property
-    def input_height(self) -> int: ...
-    @property
-    def input_format(self) -> str: ...
-    async def save(self, path: str, options: Optional[ImageOptions] = None) -> None: ...
-    async def to_buffer(self, options: Optional[ImageOptions] = None) -> FrameBuffer: ...
-    async def to_image(self, options: Optional[ImageOptions] = None) -> FrameImage: ...
+    async def save(self, path: str, options: Optional[ImageOptions] = {}) -> None: ...
+    async def to_buffer(self, options: Optional[ImageOptions] = {}) -> FrameBuffer: ...
+    async def to_image(self, options: Optional[ImageOptions] = {}) -> FrameImage: ...
 
 
 class MotionFrame(VideoFrame):
@@ -825,7 +822,7 @@ class CameraDevice(Protocol):
     async def disconnect(self) -> None: ...
     async def reboot(self) -> None: ...
     async def snapshot(self, force_new: Optional[bool] = None) -> bytes: ...
-    async def get_frames(self, options: ImageOptions = {}) -> AsyncGenerator[VideoFrame, None]: ...
+    async def get_frames(self) -> AsyncGenerator[VideoFrame, None]: ...
     async def get_motion_frames(self) -> AsyncGenerator[MotionFrame, None]: ...
     async def get_prebuffered_frames(self) -> AsyncGenerator[VideoFrame, None]: ...
     async def get_ffmpeg_path(self) -> str: ...
@@ -855,7 +852,7 @@ class CameraDevice(Protocol):
         self,
         state_name: Literal["motion"],
         event_data: MotionSetEvent,
-        frame: Optional[bytes] = None,
+        frame: Optional[VideoFrame] = None,
     ) -> None: ...
 
     @overload
@@ -892,7 +889,9 @@ class CameraDevice(Protocol):
         state_name: Literal["battery"],
         event_data: BatterySetEvent,
     ) -> None: ...
-    async def update_state(self, state_name: str, event_data: Any, frame: Optional[bytes] = None) -> None: ...
+    async def update_state(
+        self, state_name: str, event_data: Any, frame: Optional[VideoFrame] = None
+    ) -> None: ...
 
     @overload
     def on_state_change(
